import tensorflow as tf
import tensorflow_datasets as tfds
import os
import json
import time
import argparse
num_epochs = 5
batch_size_per_replica = 64
learning_rate = 0.001

parser = argparse.ArgumentParser(description='manual to this script')
parser.add_argument('--num_workers', type=int, default = 1, help='总节点数')
parser.add_argument('--worker_no', type=int, default = 0, help='worker序号')
args = parser.parse_args()

num_workers = args.num_workers
os.environ['TF_CONFIG'] = json.dumps({
    'cluster': {
        'worker': ["192.168.1.7:20005", "192.168.1.8:20006"]
    },
    'task': {'type': 'worker', 'index':args.worker_no}
})
strategy = tf.distribute.experimental.MultiWorkerMirroredStrategy()
batch_size = batch_size_per_replica * num_workers
 
def resize(image, label):
    image = tf.image.resize(image, [224, 224]) / 255.0
    return image, label
 
dataset = tfds.load("cats_vs_dogs",download=False, data_dir='./', split=tfds.Split.TRAIN, as_supervised=True)
dataset = dataset.map(resize).shuffle(1024).batch(batch_size)
 
with strategy.scope():
    model = tf.keras.applications.MobileNetV2()
    model.compile(
        optimizer=tf.keras.optimizers.Adam(learning_rate=learning_rate),
        loss=tf.keras.losses.sparse_categorical_crossentropy,
        metrics=[tf.keras.metrics.sparse_categorical_accuracy]
    )
start=time.perf_counter() 
model.fit(dataset, epochs=num_epochs)
end=time.perf_counter()
print('time taken is %f' % (end-start))
